
import 'package:easy_localization/src/public_ext.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bounceable/flutter_bounceable.dart';
import 'package:flutter_flushbar/flutter_flushbar.dart';
import 'package:flutter_styled_toast/flutter_styled_toast.dart';
import 'package:flutter_svg/svg.dart';

import '../../../widget/custom/spaces.dart';
import '../../../widget/text/custom_text_default_field.dart';
import '../../../widget/text/custom_text_medium_bold_field.dart';
import '../../../widget/text/custom_text_small_field.dart';
import '../../values/sizes.dart';

Flushbar? flushbar;

class AnimationHelper {
  static ToastFuture ShowToastCustom(
      {required BuildContext context,
      String? lable,
      bool? isHome = true,
      required VoidCallback? onTap}) {
    return showToastWidget(
        Container(
          margin: EdgeInsets.all(8),
          padding: EdgeInsets.symmetric(horizontal: 12, vertical: 8),
          decoration: BoxDecoration(
            color: Color(0xFF3aadaa),
          ),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Expanded(
                  child: CustomTextSmallField(
                label: lable,
                maxLine: 3,
                color: Colors.white,
              )),
              SpaceW4(),
              Bounceable(
                onTap: onTap,
                child: Container(
                  color: Colors.transparent,
                  width: Sizes.WIDTH_90,
                  height: Sizes.HEIGHT_42,
                  padding: const EdgeInsets.symmetric(horizontal: 4),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      SvgPicture.asset(
                        "assets/images/ic_cart.svg",
                        width: Sizes.WIDTH_24,
                        height: Sizes.HEIGHT_24,
                        color: Colors.white,
                      ),
                      SpaceH2(),
                      Text(
                        "text_view_cart".tr(),
                        style: TextStyle(
                            color: Colors.white,
                            fontSize: Sizes.TEXT_SIZE_12,
                            fontWeight: FontWeight.w900,
                            fontStyle: FontStyle.normal),
                        maxLines: 1,
                      ),
                    ],
                  ),
                ),
              )
            ],
          ),
        ),
        context: context,
        animation: StyledToastAnimation.slideFromBottomFade,
        reverseAnimation: StyledToastAnimation.slideToBottomFade,
        startOffset: Offset(0.0, 30.0),
        reverseEndOffset: Offset(0.0, 30.0),
        position: StyledToastPosition(
            align: Alignment.bottomCenter, offset: isHome! ? 54.0 : 5),
        duration: Duration(milliseconds: 2000),
        animDuration: Duration(milliseconds: 200),
        curve: Curves.linearToEaseOut,
        dismissOtherToast: true,
        isIgnoring: false,
        reverseCurve: Curves.fastOutSlowIn);
  }

  static void CustomAddFlushToast(
      {required BuildContext context,
      required title,
      required content,
      required callback}) async {
    if (flushbar != null) {
      flushbar?.dismiss();
    }
    flushbar = await Flushbar(
      flushbarStyle: FlushbarStyle.FLOATING,
      backgroundColor: Color(0xFF3aadaa),
      flushbarPosition: FlushbarPosition.BOTTOM,
      titleText: CustomTextMediumBoldField(
          label: title, color: Colors.white, maxLine: 1),
      messageText: CustomTextDefaultField(
          label: content, color: Colors.white, maxLine: 1),
      isDismissible: true,
      margin: EdgeInsets.all(4),
      borderRadius: BorderRadius.circular(6),
      duration: const Duration(milliseconds: 2000),
      animationDuration: const Duration(milliseconds: 200),
      mainButton: TextButton(
        onPressed: () {
          flushbar?.dismiss();
          callback();
        },
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            SvgPicture.asset(
              "assets/images/ic_cart.svg",
              width: Sizes.WIDTH_24,
              height: Sizes.HEIGHT_24,
              color: Colors.white,
            ),
            SpaceH2(),
            Text(
              "text_view_cart".tr(),
              style: TextStyle(
                  color: Colors.white,
                  fontSize: Sizes.TEXT_SIZE_12,
                  fontWeight: FontWeight.w900,
                  fontStyle: FontStyle.normal),
              maxLines: 1,
            ),
          ],
        ),
      ),
    )
      ..show(context);
  }

  static void CustomNetworkFlushToast(
      {required BuildContext context, bool isConnect = true}) async {
    try {
      if (flushbar != null) {
        flushbar?.dismiss();
      }
      flushbar = await Flushbar(
          flushbarStyle: FlushbarStyle.FLOATING,
          dismissDirection: FlushbarDismissDirection.HORIZONTAL,
          backgroundColor: isConnect
              ? Colors.green[300]!.withOpacity(0.6)
              : Colors.black87.withOpacity(0.6),
          flushbarPosition: FlushbarPosition.TOP,
          messageText: CustomTextSmallField(
              label: isConnect
                  ? "text_data_online".tr()
                  : "text_data_offline".tr(),
              color: Colors.white,
              maxLine: 1),
          isDismissible: true,
          blockBackgroundInteraction: true,
          duration: isConnect ? const Duration(milliseconds: 3000) : null,
          animationDuration: const Duration(seconds: 1),
          leftBarIndicatorColor: isConnect ? Colors.green : Colors.red,
          icon: isConnect
              ? Icon(CupertinoIcons.wifi)
              : Icon(CupertinoIcons.wifi_exclamationmark))
        ..show(context);
    } catch (e) {
      Navigator.of(context).pop();
    }
  }

  static void CustomNetworkWarningToast(
      {required BuildContext context,
      bool? isRetryCallback,
      Function()? retryCallbak}) async {
    try {
      if (flushbar != null) {
        flushbar?.dismiss();
      }
      flushbar = await Flushbar(
          flushbarStyle: FlushbarStyle.FLOATING,
          dismissDirection: FlushbarDismissDirection.HORIZONTAL,
          backgroundColor: Colors.black87.withOpacity(0.6),
          flushbarPosition: FlushbarPosition.BOTTOM,
          messageText: CustomTextSmallField(
              label: "text_network_error".tr(),
              color: Colors.white,
              maxLine: 1),
          isDismissible: true,
          blockBackgroundInteraction: true,
          duration: const Duration(milliseconds: 3000),
          animationDuration: const Duration(seconds: 200),
          leftBarIndicatorColor: Colors.red,
          mainButton: isRetryCallback == false
              ? TextButton(
                  onPressed: () {
                    flushbar?.dismiss();
                    if (retryCallbak != null) {
                      retryCallbak();
                    }
                  },
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Icon(
                        CupertinoIcons.restart,
                        color: Colors.white,
                      ),
                      SpaceH2(),
                      Text(
                        "text_retry".tr(),
                        style: TextStyle(
                            color: Colors.white,
                            fontSize: Sizes.TEXT_SIZE_12,
                            fontWeight: FontWeight.w900,
                            fontStyle: FontStyle.normal),
                        maxLines: 1,
                      ),
                    ],
                  ),
                )
              : Container(),
          icon: Icon(CupertinoIcons.wifi_exclamationmark))
        ..show(context);
    } catch (e) {
      if (flushbar != null) {
        await flushbar?.dismiss();
      }
    }
  }
}
